@@ -93,7 +93,7 @@ public final class KerberosUtils {
                         final PasswordCallback passCallback = (PasswordCallback) callback;
                         passCallback.setPassword(password.toCharArray());
                     } else {
-                        System.out.println(callback.getClass().getName() + ":" + callback.toString());
+                        LOG.error("Unknown callback class: " + callback.getClass().getName() + '#' + callback.toString());
                     }
                 }
             }
